@@ -1,35 +1,18 @@
-"""
-The MIT License (MIT)
-
-Copyright (c) 2021-2025 null8626
-
-Permission is hereby granted, free of charge, to any person obtaining a copy
-of this software and associated documentation files (the "Software"), to deal
-in the Software without restriction, including without limitation the rights
-to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is
-furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in all
-copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-SOFTWARE.
-"""
+# SPDX-License-Identifier: MIT
+# SPDX-FileCopyrightText: 2021-2026 null8626
 
 from datetime import datetime, date, time
-from collections.abc import Iterable
-from typing import Optional
+from collections.abc import Iterator
+from typing import TYPE_CHECKING
 
-from .enums import Phase, Locale, HeatIndex
-from .constants import _Unit, LATLON_REGEX
+from .enums import Phase, HeatIndex
+from .constants import LATLON_REGEX
 from .base import BaseForecast
 
+if TYPE_CHECKING:
+  from .constants import _Unit
+  from .enums import Locale
+
 
 class HourlyForecast(BaseForecast):
   """A weather forecast for a specific hour."""
@@ -45,7 +28,6 @@ class HourlyForecast(BaseForecast):
     'chances_of_sunshine',
     'chances_of_thunder',
     'chances_of_windy',
-    'cloud_cover',
     'time',
     'dew_point',
     'heat_index',
@@ -83,9 +65,6 @@ class HourlyForecast(BaseForecast):
   chances_of_windy: int
   """Chances of windy in percent."""
 
-  cloud_cover: int
-  """The cloud cover value in percent."""
-
   time: 'time'
   """The local time in hours and minutes."""
 
@@ -101,7 +80,7 @@ class HourlyForecast(BaseForecast):
   wind_gust: int
   """The wind gust value in either kilometers/hour or miles/hour."""
 
-  def __init__(self, json: dict, unit: _Unit, locale: Locale):
+  def __init__(self, json: dict, unit: '_Unit', locale: 'Locale'):
     # For inheritance purposes.
     if 'temp_C' not in json:
       json['temp_C'] = json.pop('tempC')
@@ -122,7 +101,6 @@ class HourlyForecast(BaseForecast):
     self.chances_of_sunshine = int(json['chanceofsunshine'])
     self.chances_of_thunder = int(json['chanceofthunder'])
     self.chances_of_windy = int(json['chanceofwindy'])
-    self.cloud_cover = int(json['cloudcover'])
     self.time = time() if len(t) < 3 else datetime.strptime(t, '%H%M').time()
     self.dew_point = int(json[f'DewPoint{unit.temperature}'])
     self.heat_index = HeatIndex._new(
@@ -135,7 +113,7 @@ class HourlyForecast(BaseForecast):
     super().__init__(json, unit, locale)
 
   def __repr__(self) -> str:
-    return f'<{__class__.__name__} time={self.time!r} temperature={self.temperature} description={self.description!r} kind={self.kind!r}>'
+    return f'<{__class__.__module__}.{__class__.__name__} time={self.time!r} temperature={self.temperature} kind={self.kind!r}>'
 
 
 class DailyForecast:
@@ -163,16 +141,16 @@ class DailyForecast:
   moon_phase: Phase
   """The moon's phase."""
 
-  moonrise: Optional[time]
+  moonrise: time | None
   """The local time when the moon rises."""
 
-  moonset: Optional[time]
+  moonset: time | None
   """The local time when the moon sets."""
 
-  sunrise: Optional[time]
+  sunrise: time | None
   """The local time when the sun rises."""
 
-  sunset: Optional[time]
+  sunset: time | None
   """The local time when the sun sets."""
 
   date: 'date'
@@ -196,7 +174,7 @@ class DailyForecast:
   hourly_forecasts: list[HourlyForecast]
   """The hourly forecasts of this day."""
 
-  def __init__(self, json: dict, unit: _Unit, locale: Locale):
+  def __init__(self, json: dict, unit: '_Unit', locale: 'Locale'):
     astronomy = json['astronomy'][0]
 
     self.moon_illumination = int(astronomy['moon_illumination'])
@@ -216,19 +194,19 @@ class DailyForecast:
     ]
 
   @staticmethod
-  def __parse_time(timestamp: str) -> Optional[time]:
+  def __parse_time(timestamp: str) -> time | None:
     try:
       return datetime.strptime(timestamp, '%I:%M %p').time()
-    except ValueError:
+    except ValueError:  # pragma: nocover
       ...
 
   def __repr__(self) -> str:
-    return f'<{__class__.__name__} date={self.date!r} temperature={self.temperature}>'
+    return f'<{__class__.__module__}.{__class__.__name__} date={self.date!r} temperature={self.temperature}>'
 
   def __len__(self) -> int:
     return len(self.hourly_forecasts)
 
-  def __iter__(self) -> Iterable[HourlyForecast]:
+  def __iter__(self) -> Iterator[HourlyForecast]:
     return iter(self.hourly_forecasts)
 
 
@@ -266,7 +244,7 @@ class Forecast(BaseForecast):
   daily_forecasts: list[DailyForecast]
   """Daily weather forecasts in this location."""
 
-  def __init__(self, json: dict, unit: _Unit, locale: Locale):
+  def __init__(self, json: dict, unit: '_Unit', locale: 'Locale'):
     current = json['current_condition'][0]
     nearest = json['nearest_area'][0]
 
@@ -280,9 +258,12 @@ class Forecast(BaseForecast):
       req = next(filter(lambda x: x['type'] == 'LatLon', json['request']))
       match = LATLON_REGEX.match(req['query'])
 
-      self.coordinates = (float(match[1]), float(match[2]))
-    except (KeyError, IndexError, StopIteration):
-      self.coordinates = (float(nearest['latitude']), float(nearest['longitude']))
+      if TYPE_CHECKING:
+        assert match is not None
+
+      self.coordinates = float(match[1]), float(match[2])
+    except (AssertionError, KeyError, StopIteration):
+      self.coordinates = float(nearest['latitude']), float(nearest['longitude'])
 
     self.daily_forecasts = [
       DailyForecast(elem, unit, locale) for elem in json['weather']
@@ -291,10 +272,10 @@ class Forecast(BaseForecast):
     super().__init__(current, unit, locale)
 
   def __repr__(self) -> str:
-    return f'<{__class__.__name__} location={self.location!r} datetime={self.datetime!r} temperature={self.temperature}>'
+    return f'<{__class__.__module__}.{__class__.__name__} location={self.location!r} datetime={self.datetime!r} temperature={self.temperature}>'
 
   def __len__(self) -> int:
     return len(self.daily_forecasts)
 
-  def __iter__(self) -> Iterable[DailyForecast]:
+  def __iter__(self) -> Iterator[DailyForecast]:
     return iter(self.daily_forecasts)
